#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef NO_PLUGINS
#undef HAVE_LIBGD
#undef HAVE_LIBZ
#undef HAVE_LIBBZ
#undef HAVE_GETOPT_H
#undef HAVE_GETOPT_LONG
#undef HAVE_GD_GD_H
#undef HAVE_LIBADNS
#undef HAVE_LIBXML
#undef HAVE_FUNCTION
#undef HAVE_FLOWTOOLS
#undef HAVE_SYBASE
#undef HAVE_MYSQL
#undef HAVE_EXPAT
